==> huaweicloudsdkworkspaceapp-3.1.76-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/update_tsvi_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTsviReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[UpdateTsvi]'
    }

    attribute_map = {
        'items': 'items'
    }

    def __init__(self, items=None):
        """UpdateTsviReq

        The model defined in huaweicloud sdk

        :param items: 批量请求列表，一次请求数量区间 [1, 20]
        :type items: list[:class:`huaweicloudsdkworkspaceapp.v1.UpdateTsvi`]
        """
        
        

        self._items = None
        self.discriminator = None

        self.items = items

    @property
    def items(self):
        """Gets the items of this UpdateTsviReq.

        批量请求列表，一次请求数量区间 [1, 20]

        :return: The items of this UpdateTsviReq.
        :rtype: list[:class:`huaweicloudsdkworkspaceapp.v1.UpdateTsvi`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this UpdateTsviReq.

        批量请求列表，一次请求数量区间 [1, 20]

        :param items: The items of this UpdateTsviReq.
        :type items: list[:class:`huaweicloudsdkworkspaceapp.v1.UpdateTsvi`]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTsviReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.125-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/update_tsvi_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateTsviReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[UpdateTsvi]'
    }

    attribute_map = {
        'items': 'items'
    }

    def __init__(self, items=None):
        """UpdateTsviReq

        The model defined in huaweicloud sdk

        :param items: 批量请求列表，一次请求数量区间 [1, 20]。
        :type items: list[:class:`huaweicloudsdkworkspaceapp.v1.UpdateTsvi`]
        """
        
        

        self._items = None
        self.discriminator = None

        self.items = items

    @property
    def items(self):
        """Gets the items of this UpdateTsviReq.

        批量请求列表，一次请求数量区间 [1, 20]。

        :return: The items of this UpdateTsviReq.
        :rtype: list[:class:`huaweicloudsdkworkspaceapp.v1.UpdateTsvi`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this UpdateTsviReq.

        批量请求列表，一次请求数量区间 [1, 20]。

        :param items: The items of this UpdateTsviReq.
        :type items: list[:class:`huaweicloudsdkworkspaceapp.v1.UpdateTsvi`]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateTsviReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
